@@ -1,9 +1,9 @@
 <?php
 include_once(dirname(__FILE__).'/includes/utils.inc.php');
 
-$this_version = '4.5.9';
+$this_version = '4.5.10';
 $link_target = 'main';
-$theme = $cfg['theme'] ?? 'dark';
+$theme = isset($cfg['theme']) ? $cfg['theme'] : 'dark';
 if ($theme != 'dark' && $theme != 'light') {
 	$theme = 'dark';
 }
@@ -30,7 +30,7 @@ if ($theme != 'dark' && $theme != 'light') {
 	<div class="navsectionlinks">
 		<ul class="navsectionlinks">
 			<li><a href="main.php" target="<?php echo $link_target;?>">Home</a></li>
-			<li><a href="https://go.nagios.com/nagioscore/docs" target="_blank">Documentation</a></li>
+			<li><a href="https://assets.nagios.com/downloads/nagioscore/docs/nagioscore/4/en/" target="_blank">Documentation</a></li>
 		</ul>
 	</div>
 </div>
